==> ulyxex.0.0.6.with-tinyMce.zip: pages/code/admin_article_add.php <==
<?php
class ArticleAdd extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function add_article() {
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		if ($_POST['subject'] == "") $_POST['subject'] = $this->tr->w("no subject");
		/* in case of page no exist		*/
		$siteDat = $this->home_params();
		$pageId = isset($_POST['pageid'])?$this->h->num($_POST['pageid']):$siteDat['SANDBOXID'];
		$content = $this->h->safe($_POST['content']);
		$query = "INSERT INTO ".ARTICLES."  (SUBJECT,USERID,DATE,CONTENT,HIDE,PAGEID) VALUES (".
										"'".$this->h->safe($_POST['subject'])."',".$this->h->num($_POST['userid']).",'".
										$date."','".$content."',".
										$this->h->num($hide).",".$pageId.");";
		$query = $this->q($query);
		$result = $this->h->h3($this->tr->ws("article").strip_tags($_POST['subject']).$this->tr->wsp("created !"));
		return $result;
	}
	public function add_article_form() {
		$siteDat = $this->home_params();
		$content = $this->h->input("hidden","add",1);
		$content .= $this->h->input("hidden","userid",$_SESSION['userid']);
		$content .=  $this->h->p($this->tr->ws("hide").$this->h->input("checkbox","hide","on"));
		$content .= ($_SESSION['level'] < 4)?  $this->h->p($this->tr->ws("choose page").$this->SelectUserPages("pageid",$siteDat['PAGEID'])): $this->h->p("SandBox").$this->h->input("hidden","pageid",$siteDat['SANDBOXID']);
		$content .=  $this->h->p( $this->tr->w("subject (not displayed only info)")).$this->h->p($this->h->input("content","subject","","size=".FIELDWIDTH));
		$content .=  $this->h->p($this->tr->w("content")).$this->h->p($this->h->textarea("","content",array(12,FIELDWIDTH)));
		$content .=  $this->h->p($this->h->input("submit","save",$this->tr->w("save")));
		$result = $this->h->form($content,"article","post","admin.php?action=add_article");
		return $result;
	}
}
?>

==> ulyxex.0.1.0.with-tinyMce.zip: pages/code/admin_article_add.php <==
<?php
class ArticleAdd extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
        $this->tree = New Tree();
	}
	public function add_article() {
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		if ($_POST['subject'] == "") $_POST['subject'] = $this->tr->w("no subject");
		/* in case of page no exist		*/
		$siteDat = $this->home_params();
		$pageId = isset($_POST['parent'])?$this->h->num($_POST['parent']):$siteDat['SANDBOXID'];
		$content = $this->h->safe($_POST['content']);
		$query = "INSERT INTO ".ARTICLES."  (SUBJECT,USERID,DATE,CONTENT,HIDE,PAGEID) VALUES (".
										"'".$this->h->safe($_POST['subject'])."',".$this->h->num($_POST['userid']).",'".
										$date."','".$content."',".
										$this->h->num($hide).",".$pageId.");";
		$query = $this->q($query);
		$result = $this->h->h3($this->tr->ws("article").strip_tags($_POST['subject']).$this->tr->wsp("created !"));
		return $result;
	}
	public function add_article_form() {
		$siteDat = $this->home_params();
		$content = $this->h->input("hidden","add",1);
		$content .= $this->h->input("hidden","userid",$_SESSION['userid']);
		$content .=  $this->h->p($this->tr->ws("hide").$this->h->input("checkbox","hide","on"));
		$content .= ($_SESSION['level'] < 4)?  $this->h->p($this->tr->ws("choose page").$this->tree->pathsSelect(null,0)): $this->h->p("SandBox").$this->h->input("hidden","pageid",$siteDat['SANDBOXID']);
		$content .=  $this->h->p( $this->tr->w("subject (not displayed only info)")).$this->h->p($this->h->input("content","subject","","size=".FIELDWIDTH));
		$content .=  $this->h->p($this->tr->w("content")).$this->h->p($this->h->textarea("","content",array(12,FIELDWIDTH)));
		$content .=  $this->h->p($this->h->input("submit","save",$this->tr->w("save")));
		$result = $this->h->form($content,"article","post","admin.php?action=add_article");
		return $result;
	}
}
?>
